Learn R Programming

table.express (version 0.1.1)

mutate-table.express: Add or update columns

Description

Add or update columns of a data.table::data.table, possibly by reference using :=.

Usage

# S3 method for ExprBuilder
mutate(.data, ..., .unquote_names = TRUE,
  .parse = getOption("table.express.parse", FALSE),
  .chain = getOption("table.express.chain", TRUE))

Arguments

.data

An instance of ExprBuilder.

...

Mutation clauses.

.unquote_names

Passed to rlang::enexprs(). Set to FALSE if you want to pass the single := expression.

.parse

Logical. Whether to apply rlang::parse_expr() to obtain the expressions.

.chain

Logical. Should a new frame be automatically chained to the expression if the clause being set already exists?

Details

To see more examples, check the vignette, or the table.express-package entry.

Examples

Run this code
# NOT RUN {
data("mtcars")
data.table::as.data.table(mtcars) %>%
    start_expr %>%
    mutate(mpg_squared = mpg ^ 2)

# }

Run the code above in your browser using DataLab