Learn R Programming

table.express (version 0.1.1)

where-table.express: Where clause

Description

Clause for subsetting rows.

Usage

where(.data, ...)

# S3 method for ExprBuilder where(.data, ..., .collapse = `&`, .parse = getOption("table.express.parse", FALSE), .chain = getOption("table.express.chain", TRUE))

Arguments

.data

The input data.

...

Arguments for the specific methods.

.collapse

A boolean function which will be used to "concatenate" all conditions in ....

.parse

Logical. Whether to apply rlang::parse_expr() to obtain the expressions.

.chain

Logical. Should a new frame be automatically chained to the expression if the clause being set already exists?

Details

To see more examples, check the vignette, or the table.express-package entry.

Examples

Run this code
# NOT RUN {
data("mtcars")

data.table::as.data.table(mtcars) %>%
    start_expr %>%
    where(vs == 0, am == 1)

# }

Run the code above in your browser using DataLab