powered by
Helper to filter specifying the on part of the data.table::data.table query.
on
filter_on(.data, ..., nomatch = getOption("datatable.nomatch"), mult = "all", .chain = getOption("table.express.chain", TRUE))
An instance of ExprBuilder.
Key-value pairs, see details.
See data.table::data.table.
Logical. Should a new frame be automatically chained to the expression if the clause being set already exists?
The key-value pairs in '...' are processed as follows:
The names are used as on in the data.table frame.
data.table
The values are packed in a list and used as i in the data.table frame.
i
Thus, all pairs must be named.
To see more examples, check the vignette, or the table.express-package entry.
# NOT RUN { data("mtcars") data.table::as.data.table(mtcars) %>% start_expr %>% filter_on(cyl = 4, gear = 5) # }
Run the code above in your browser using DataLab