powered by
Add or update columns of a data.table::data.table, possibly by reference using :=.
:=
# S3 method for ExprBuilder mutate(.data, ..., .unquote_names = TRUE, .parse = getOption("table.express.parse", FALSE), .chain = getOption("table.express.chain", TRUE))
An instance of ExprBuilder.
Mutation clauses.
Passed to rlang::enexprs(). Set to FALSE if you want to pass the single := expression.
rlang::enexprs()
FALSE
Logical. Whether to apply rlang::parse_expr() to obtain the expressions.
rlang::parse_expr()
Logical. Should a new frame be automatically chained to the expression if the clause being set already exists?
To see more examples, check the vignette, or the table.express-package entry.
# NOT RUN { data("mtcars") data.table::as.data.table(mtcars) %>% start_expr %>% mutate(mpg_squared = mpg ^ 2) # }
Run the code above in your browser using DataLab