If length(...) == 1L and the expression is a call to : (e.g. a:c), a numeric, or a call to
tidyselect::select_helpers, then it will be taken as the single expression for the select
clause, otherwise everything in ... will be wrapped in a call to base::list().
To see more examples, check the
vignette, or the
table.express-package entry.